A Natural Language Understanding and Execution library for Python

This library turns a question, statement or command from a ordinary human language directly into Python executable code. It is completely rule-based and you as a developer define the code that is to be executed. The executable code can be any Python code, and there is specially suited for database access.

Note: while on version 0 I may introduce backward-incompatible changes as I'm looking for the right form.

## Features

* Python code as semantic attachments to parsing rules
* A configurable processing pipeline
* Interaction with any type of database

## Requires

* Python 3.10 (or higher)

## Setup

To add the project to your virtual environment, use

    pip install richard

## Documentation

Documentation is available at [readthedocs](https://richard.readthedocs.io/).

